# GisPandas针对栅格数据进行统计的python包
GisPandas是一个为栅格数据处理、分析和可视化而开发的Python包。GisPandas为常见栅格数据进行行政区划统计提供了快速而简洁的方法。GisPandas为遥感影像分类的后处理过程提供高效的处理，代码简洁、高效、灵活、易用，可以用简洁的代码实现复杂的数据任务。
# 主要功能
目前，GisPandas主要提供以下方法：
栅格数据进行阿尔伯斯等面积投影，根据矢量区划会计算面积导出json。
# 安装
pip install gispandas
# 相关链接
本项目的github页面：https://github.com/mxhou/gispandas/
有bug请在这个页面提交：https://github.com/mxhou/gispandas/issues
